require File.expand_path('spec_helper', __dir__)

describe Danger::DangerCommitLint::SubjectLengthCheck do
  describe '#fail?' do
    let(:commit_subject) { 'This is a common valid commit message' }

    let(:message) do
      {
        subject: commit_subject
      }
    end

    subject do
      described_class.new(message).fail?
    end

    it { expect(subject).to be_falsy }

    context 'when message is invalid' do
      let(:commit_subject) do
        'This is a really long subject line and should result in an error'
      end

      it { expect(subject).to be_truthy }
    end

    context 'when message is a merge commit generated by git' do
      let(:commit_subject) do
        "Merge branch 'ignore-length-on-git-merge-commits' into master"
      end

      it { expect(subject).to be_falsy }
    end

    context 'when message is a merge commit generated by GitHub' do
      let(:commit_subject) do
        'Merge pull request #1234 from jonallured/ignore-length-merge-commits'
      end

      it { expect(subject).to be_falsy }
    end
  end
end
